@@ -1,8 +1,9 @@
 #ifndef __GDICT_ABOUT_H_
 #define __GDICT_ABOUT_H_
 
-/* $Id: gdict-about.h,v 1.1.1.1 1999/07/03 00:17:33 spapadim Exp $ */
+/* $Id: gdict-about.h,v 1.3 2004/02/12 09:14:34 dsmit Exp $ */
 
+#include "gtk/gtkwindow.h"
 /*
  *  Papadimitriou Spiros <spapadim@cs.cmu.edu>
  *  Mike Hughes <mfh@psilord.com>
@@ -14,7 +15,8 @@
  *
  */
 
-extern void gdict_about (void);
+GtkWidget *gdict_about_new (void);
+extern void gdict_about (GtkWindow *parent);
 
 #endif /* __GDICT_ABOUT_H_ */
 
