@@ -44,6 +44,7 @@
 #include "gsearchtool.h"
 #include "gsearchtool-support.h"
 #include "gsearchtool-callbacks.h"
+#include "gsearchtool-alert-dialog.h"
 
 static GnomeUIInfo popup_menu[] = {
 	GNOMEUIINFO_ITEM_STOCK (N_("_Open"), 
@@ -103,11 +104,13 @@ help_cb (GtkWidget 	*widget,
 	if (error) {
 		GtkWidget *dialog;
 
-		dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-		                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-						     GTK_BUTTONS_OK,
-		                                     _("Could not open help document"),
-						     error->message);
+		dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+		                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+						   GTK_MESSAGE_ERROR,
+						   GTK_BUTTONS_OK,
+						   _("Could not open help document."),
+						   error->message,
+						   NULL);	
 
                 g_signal_connect (G_OBJECT (dialog),
                                   "response",
@@ -119,10 +122,10 @@ help_cb (GtkWidget 	*widget,
 }
 
 void
-click_check_button_cb (GtkWidget	*widget, 
-	       	       gpointer 	data)
+click_expander_cb (GtkWidget	*widget, 
+	       	   gpointer 	data)
 {
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget))) {
+	if (gtk_expander_get_expanded (GTK_EXPANDER (widget))) {
 		gtk_widget_show (interface.additional_constraints);
 		gtk_window_set_geometry_hints (GTK_WINDOW (interface.main_window), 
 		                               GTK_WIDGET (interface.main_window),
@@ -227,6 +230,7 @@ remove_constraint_cb (GtkWidget 	*widget,
 	
 	set_constraint_selected_state (constraint->constraint_id, FALSE);	
 	set_constraint_gconf_boolean (constraint->constraint_id, FALSE);	
+	g_free (constraint);
 }
 
 void
@@ -306,26 +310,41 @@ open_file_cb (GtkWidget 	*widget,
 						     (GtkTreeModel **)&interface.model);
 	
 	if (g_list_length (list) > SILENT_WINDOW_OPEN_LIMIT) {
-	
 		GtkWidget *dialog;
-		gchar     *title;
-		gchar     *message;
+		GtkWidget *button;
+		gchar     *primary;
+		gchar     *secondary;
 		gint      response;
 
-		title = g_strdup_printf (_("Open %d documents?"), g_list_length (list));
-		message = g_strdup_printf (_("This will open %d separate documents. Are you sure you want to do this?"),
+		primary = g_strdup_printf (ngettext ("Are you sure you want to open %d document?",
+						     "Are you sure you want to open %d documents?",
+						      g_list_length (list)),
 		                           g_list_length (list));
+		
+		secondary = g_strdup_printf (ngettext ("This will open %d separate window.",
+						       "This will open %d separate windows.",
+						       g_list_length (list)),
+		                             g_list_length (list));
+		
+		dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+		                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+						   GTK_MESSAGE_QUESTION,
+						   GTK_BUTTONS_CANCEL,
+						   primary,
+						   secondary,
+						   NULL);
 
-		dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-			                             0 /* flags */,
-						     GTK_BUTTONS_OK_CANCEL,
-						     title,
-						     message);
+		button = gtk_button_new_from_stock ("gtk-open");
+		GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+		gtk_widget_show (button);
+
+		gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
+		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 		
 		response = gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
-		g_free (title);        
-		g_free (message);
+		g_free (primary);        
+		g_free (secondary);
 		
 		if (response == GTK_RESPONSE_CANCEL) {
 			g_list_free (list);
@@ -356,34 +375,67 @@ open_file_cb (GtkWidget 	*widget,
 			file = g_build_filename (utf8_path, utf8_name, NULL);
 			locale_file = g_locale_from_utf8 (file, -1, NULL, NULL, NULL);
 			
-			if (is_component_action_type (locale_file) 
-		    	    && is_nautilus_running ()) {
-				open_file_with_nautilus (locale_file);
+			if (!g_file_test (locale_file, G_FILE_TEST_EXISTS)) {
+		
+				GtkWidget      *dialog;
+				gchar          *primary;
+				gchar          *secondary;
+			
+				primary = g_strdup_printf (_("Could not open document \"%s\"."), 
+			                           g_path_get_basename (utf8_name));
+					
+				secondary = g_strdup  (_("The document does not exist."));
+
+				dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+			    	                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+								   GTK_MESSAGE_ERROR,
+								   GTK_BUTTONS_OK,
+								   primary,
+								   secondary,
+								   NULL);
+			
+				gtk_dialog_run (GTK_DIALOG (dialog));
+		
+				gtk_tree_selection_unselect_iter (GTK_TREE_SELECTION (interface.selection), &iter);
+				gtk_widget_destroy (GTK_WIDGET(dialog));
+				g_free (primary);
+				g_free (secondary);
 			}
-			else {
-				if (open_file_with_application (locale_file) == FALSE) {
+			else if (open_file_with_application (locale_file) == FALSE) {
 				
-					if (launch_file (locale_file) == FALSE) {
+				if (launch_file (locale_file) == FALSE) {
+					
+					if ((is_nautilus_running ()) &&
+					    ((g_file_test (locale_file, G_FILE_TEST_IS_DIR)) ||
+					     (is_component_action_type (locale_file)))) {
+						open_file_with_nautilus (locale_file);
+					}
+					else {
 						GtkWidget *dialog;
-						gchar     *title;
-						gchar     *text;
+						gchar     *primary;
+						gchar     *secondary;
+
+						primary = g_strdup_printf (_("Could not open document \"%s\"."),
+									   g_path_get_basename (file));
+						
+						secondary = g_strdup (_("There is no installed viewer capable "
+						                        "of displaying the document."));	
+						
+						dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+		                                                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+						                                   GTK_MESSAGE_ERROR,
+						                                   GTK_BUTTONS_OK,
+						                                   primary,
+						                                   secondary,
+						                                   NULL);	
 
-						title = g_strdup_printf (_("Could not open document \"%s\""),
-									 g_path_get_basename (file));
-						text = g_strdup (_("There is no installed viewer capable of displaying the document."));	
-							
-						dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-						                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-										     GTK_BUTTONS_OK,
-										     title,
-										     text);
                 				g_signal_connect (G_OBJECT (dialog),
                         				"response",
                         				G_CALLBACK (gtk_widget_destroy), NULL);
 
 	                			gtk_widget_show (dialog);
-						g_free (title);
-						g_free (text);
+						g_free (primary);
+						g_free (secondary);
 					}
 				}
 			} 
@@ -412,23 +464,40 @@ open_folder_cb (GtkWidget 	*widget,
 	
 	if (g_list_length (list) > SILENT_WINDOW_OPEN_LIMIT) {
 		GtkWidget *dialog;
-		gchar     *title;
-		gchar     *message;
+		GtkWidget *button;
+		gchar     *primary;
+		gchar     *secondary;
 		gint      response;
 
-		title = g_strdup_printf (_("Open %d folders?"), g_list_length (list));
-		message = g_strdup_printf (_("This will open %d separate folders. Are you sure you want to do this?"),
+		primary = g_strdup_printf (ngettext ("Are you sure you want to open %d folder?",
+						     "Are you sure you want to open %d folders?",
+						      g_list_length (list)),
 		                           g_list_length (list));
+		
+		secondary = g_strdup_printf (ngettext ("This will open %d separate window.",
+						       "This will open %d separate windows.",
+						       g_list_length (list)),
+		                             g_list_length (list));
+								  
+		dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+		                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+						   GTK_MESSAGE_QUESTION,
+						   GTK_BUTTONS_CANCEL,
+						   primary,
+						   secondary,
+						   NULL);						  
+		
+		button = gtk_button_new_from_stock ("gtk-open");
+		GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+		gtk_widget_show (button);
 
-		dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-			                             0 /* flags */,
-						     GTK_BUTTONS_OK_CANCEL,
-						     title,
-								  message);		
+		gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
+		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+								  		
 		response = gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
-		g_free (title); 
-		g_free (message);
+		g_free (primary); 
+		g_free (secondary);
 				
 		if (response == GTK_RESPONSE_CANCEL) {
 			g_list_free (list);
@@ -456,15 +525,17 @@ open_folder_cb (GtkWidget 	*widget,
 		}
 		else {
 			GtkWidget *dialog;
-			gchar *title;
+			gchar *primary;
 			
-			title = g_strdup_printf (_("Could not open folder \"%s\""), folder_utf8);
-						       
-			dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-		                                             GTK_DIALOG_DESTROY_WITH_PARENT,
-				  		             GTK_BUTTONS_OK,
-							     title,
-							     _("The nautilus file manager is not running."));
+			primary = g_strdup_printf (_("Could not open folder \"%s\"."), folder_utf8);
+			
+			dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+		                                           GTK_DIALOG_DESTROY_WITH_PARENT,
+					                   GTK_MESSAGE_ERROR,
+						           GTK_BUTTONS_OK,
+						           primary,
+						           _("The nautilus file manager is not running."),
+						           NULL);
 			
 			g_signal_connect (G_OBJECT (dialog),
                         		  "response",
@@ -473,6 +544,7 @@ open_folder_cb (GtkWidget 	*widget,
 	                gtk_widget_show (dialog);			
 			g_free (folder_locale);
 			g_free (folder_utf8);
+			g_free (primary);
 			g_list_free (list);
 			return;
 		}
@@ -528,6 +600,7 @@ move_to_trash_cb (GtkWidget 	*widget,
 	for (index = 0; index < total; index++) {
 	
 		gboolean no_files_found = FALSE;
+		GtkWidget *button;
 		GtkTreeIter iter;
 		GList *list;
 		gchar *utf8_basename;
@@ -557,8 +630,34 @@ move_to_trash_cb (GtkWidget 	*widget,
 		utf8_filename = g_build_filename (utf8_basepath, utf8_basename, NULL);
 		locale_filename = g_locale_from_utf8 (utf8_filename, -1, NULL, NULL, NULL);
 		trash_path = get_trash_path (locale_filename);
+		
+		if (!g_file_test (locale_filename, G_FILE_TEST_EXISTS)) {
+		
+			GtkWidget      *dialog;
+			gchar          *primary;
+			gchar          *secondary;
+			
+			primary = g_strdup_printf (_("Could not move \"%s\" to trash."), 
+			                           g_path_get_basename (utf8_filename));
+					
+			secondary = g_strdup  (_("The document does not exist."));
 
-		if (trash_path != NULL) {
+			dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+			                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+							   GTK_MESSAGE_ERROR,
+							   GTK_BUTTONS_OK,
+							   primary,
+							   secondary,
+							   NULL);
+			
+			gtk_dialog_run (GTK_DIALOG (dialog));
+		
+			gtk_tree_selection_unselect_iter (GTK_TREE_SELECTION (interface.selection), &iter);
+			gtk_widget_destroy (GTK_WIDGET(dialog));
+			g_free (primary);
+			g_free (secondary);
+		}
+		else if (trash_path != NULL) {
 		
 			GnomeVFSResult result;
 			gchar *destination;
@@ -575,26 +674,31 @@ move_to_trash_cb (GtkWidget 	*widget,
 			}
 			else {
 				GtkWidget *dialog;
-				gchar     *title;
-				gchar     *text;
+				gchar     *primary;
+				gchar     *secondary;
 
-				title = g_strdup_printf (_("Could not move \"%s\" to the trash."), g_path_get_basename (utf8_filename));
-				text = g_strdup_printf (_("Moving \"%s\" failed: %s."), 
-				                        utf8_filename, gnome_vfs_result_to_string (result));		
-							
-				dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-				                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-								     GTK_BUTTONS_OK,
-								     title,
-								     text);
+				primary = g_strdup_printf (_("Could not move \"%s\" to the trash."), 
+				                         g_path_get_basename (utf8_filename));
+				
+				secondary = g_strdup_printf (_("Moving \"%s\" failed: %s."), 
+				                             utf8_filename, 
+							     gnome_vfs_result_to_string (result));		
 
+				dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+				                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+								   GTK_MESSAGE_ERROR,
+								   GTK_BUTTONS_OK,
+								   primary,
+								   secondary,
+								   NULL);
+						   
                			g_signal_connect (G_OBJECT (dialog),
                        		                  "response",
                        		                  G_CALLBACK (gtk_widget_destroy), NULL);
 
                 		gtk_widget_show (dialog);
-				g_free (title);
-				g_free (text);
+				g_free (primary);
+				g_free (secondary);
 			}
 			g_free (basename);
 			g_free (destination);
@@ -602,27 +706,37 @@ move_to_trash_cb (GtkWidget 	*widget,
 		else {	
 			GnomeVFSResult result;
 			GtkWidget      *dialog;
-			gchar          *text;
-			gchar          *title;
+			gchar          *primary;
+			gchar          *secondary;
 			gint           response;
 						
-			title = g_strdup_printf (_("Do you want to delete \"%s\" permanently?"),
+			primary = g_strdup_printf (_("Do you want to delete \"%s\" permanently?"),
 			                           g_path_get_basename (utf8_filename));
 			
-			text = g_strdup_printf (_("Trash is unavailable.  Could not move \"%s\" to the trash."), utf8_filename);
+			secondary = g_strdup_printf (_("Trash is unavailable.  Could not move \"%s\" to the trash."),
+			                             utf8_filename);
 
-			dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-			                                     0 /* flags */,
-							     GTK_BUTTONS_YES_NO, /* YES/NO is actually CANCEL/DELETE */
-							     title,
-							     text);
+			dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+			                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+							   GTK_MESSAGE_QUESTION,
+							   GTK_BUTTONS_CANCEL,
+							   primary,
+							   secondary,
+							   NULL);
+			
+			button = gtk_button_new_from_stock ("gtk-delete");
+			GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+			gtk_widget_show (button);			   	
 	
+			gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
+			gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+			
 			response = gtk_dialog_run (GTK_DIALOG (dialog));
 		
 			gtk_tree_selection_unselect_iter (GTK_TREE_SELECTION (interface.selection), &iter);
 			gtk_widget_destroy (GTK_WIDGET(dialog));
-			g_free (title);
-			g_free (text);
+			g_free (primary);
+			g_free (secondary);
 						
 			if (response == GTK_RESPONSE_OK) {
 			
@@ -638,26 +752,31 @@ move_to_trash_cb (GtkWidget 	*widget,
 				}
 				else {
 					GtkWidget *dialog;
-					gchar     *title;
-					gchar     *text;
+					gchar     *primary;
+					gchar     *secondary;
 
-					title = g_strdup_printf (_("Could not delete \"%s\"."), g_path_get_basename (utf8_filename));
-					text = g_strdup_printf (_("Deleting \"%s\" failed: %s."), utf8_filename,
-					                        gnome_vfs_result_to_string (result));	
-							
-					dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-					                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-									     GTK_BUTTONS_OK,
-									     title,
-									     text);
+					primary = g_strdup_printf (_("Could not delete \"%s\"."), 
+					                           g_path_get_basename (utf8_filename));
+					
+					secondary = g_strdup_printf (_("Deleting \"%s\" failed: %s."), 
+					                             utf8_filename,
+					                             gnome_vfs_result_to_string (result));
+
+					dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+					                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+									   GTK_MESSAGE_ERROR,
+									   GTK_BUTTONS_OK,
+									   primary,
+									   secondary,
+									   NULL);
 
                 			g_signal_connect (G_OBJECT (dialog),
                         		                  "response",
                         		                  G_CALLBACK (gtk_widget_destroy), NULL);
 
 	                		gtk_widget_show (dialog);
-					g_free (title);
-					g_free (text);
+					g_free (primary);
+					g_free (secondary);
 				}						 
 			}
 		}
@@ -710,8 +829,10 @@ file_key_press_event_cb  (GtkWidget 		*widget,
 		     	  gpointer 		data)
 {		
 	if (event->keyval == GDK_space || event->keyval == GDK_Return) {
-		open_file_cb (widget, data);
-		return TRUE;
+		if (event->state != GDK_CONTROL_MASK) {
+			open_file_cb (widget, data);
+			return TRUE;
+		}
 	}
 	else if (event->keyval == GDK_Delete) {
 		move_to_trash_cb (widget, data);
@@ -836,35 +957,68 @@ file_event_after_cb  (GtkWidget 	*widget,
 			
 			file = g_build_filename (utf8_path, utf8_name, NULL);
 			locale_file = g_locale_from_utf8 (file, -1, NULL, NULL, NULL);
+		
+			if (!g_file_test (locale_file, G_FILE_TEST_EXISTS)) {
+		
+				GtkWidget      *dialog;
+				gchar          *primary;
+				gchar          *secondary;
 			
-			if (is_component_action_type (locale_file) 
-			    && is_nautilus_running ()) {
-				open_file_with_nautilus (locale_file);
-			}
-			else {
-				if (open_file_with_application (locale_file) == FALSE) {
-				
-					if (launch_file (locale_file) == FALSE) {
-						GtkWidget *dialog;
-						gchar     *title;
-						gchar     *text;
+				primary = g_strdup_printf (_("Could not open document \"%s\"."), 
+			                           g_path_get_basename (utf8_name));
+					
+				secondary = g_strdup  (_("The document does not exist."));
 
-						title = g_strdup_printf (_("Could not open document \"%s\"."), g_path_get_basename (file));
-						text = g_strdup (_("There is no installed viewer capable of displaying the document."));	
-							
-						dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-						                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-										     GTK_BUTTONS_OK,
-										     title,
-										     text);
+				dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+			    	                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+								   GTK_MESSAGE_ERROR,
+								   GTK_BUTTONS_OK,
+								   primary,
+								   secondary,
+								   NULL);
+			
+				gtk_dialog_run (GTK_DIALOG (dialog));
+		
+				gtk_tree_selection_unselect_iter (GTK_TREE_SELECTION (interface.selection), &iter);
+				gtk_widget_destroy (GTK_WIDGET(dialog));
+				g_free (primary);
+				g_free (secondary);
+			}
+			else if (open_file_with_application (locale_file) == FALSE) {
+				
+				if (launch_file (locale_file) == FALSE) {
+				
+					if ((is_nautilus_running ()) &&
+					    ((g_file_test (locale_file, G_FILE_TEST_IS_DIR)) ||
+					     (is_component_action_type (locale_file)))) {
+						open_file_with_nautilus (locale_file);
+					}
+					else {
+						GtkWidget *dialog;
+						gchar     *primary;
+						gchar     *secondary;
+
+						primary = g_strdup_printf (_("Could not open document \"%s\"."), 
+						                           g_path_get_basename (file));
+									   
+						secondary = g_strdup (_("There is no installed viewer capable "
+						                        "of displaying the document."));
+					
+						dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+						                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+										   GTK_MESSAGE_ERROR,
+										   GTK_BUTTONS_OK,
+										   primary,
+										   secondary,
+										   NULL);
 
                 				g_signal_connect (G_OBJECT (dialog),
                         				"response",
                         				G_CALLBACK (gtk_widget_destroy), NULL);
 
 	                			gtk_widget_show (dialog);
-						g_free (title);
-						g_free (text);
+						g_free (primary);
+						g_free (secondary);
 					}
 				}
 			} 
@@ -1032,95 +1186,148 @@ void
 show_file_selector_cb (GtkWidget 	*widget, 
 		       gpointer		data)
 {
-	interface.file_selector = gtk_file_selection_new(_("Save Search Results As..."));
+	interface.file_selector = gtk_file_chooser_dialog_new (_("Save Search Results As..."),
+							       GTK_WINDOW (interface.main_window),
+							       GTK_FILE_CHOOSER_ACTION_SAVE,
+							       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+							       GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+							       NULL);
 		
-	if (interface.save_results_file) gtk_file_selection_set_filename(GTK_FILE_SELECTION(interface.file_selector), 
-									interface.save_results_file);
-
-	g_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION(interface.file_selector)->ok_button), "clicked",
-				G_CALLBACK (save_results_cb), NULL);
+	if (interface.save_results_file != NULL) {  
+		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (interface.file_selector),
+		                               interface.save_results_file);
+	}
 	
-	g_signal_connect_swapped (GTK_OBJECT (GTK_FILE_SELECTION (interface.file_selector)->ok_button),
-                             	"clicked",
-                             	G_CALLBACK (gtk_widget_destroy), 
-                             	(gpointer) interface.file_selector); 
-
-   	g_signal_connect_swapped (GTK_OBJECT (GTK_FILE_SELECTION (interface.file_selector)->cancel_button),
-                             	"clicked",
-                             	G_CALLBACK (gtk_widget_destroy),
-                             	(gpointer) interface.file_selector); 
+	g_signal_connect (G_OBJECT (interface.file_selector), "response",
+			  G_CALLBACK (save_results_cb), NULL);
 
 	gtk_window_set_modal (GTK_WINDOW(interface.file_selector), TRUE);
-	gtk_window_set_transient_for (GTK_WINDOW(interface.file_selector), GTK_WINDOW(interface.main_window));
 	gtk_window_set_position (GTK_WINDOW (interface.file_selector), GTK_WIN_POS_CENTER_ON_PARENT);
 
 	gtk_widget_show (GTK_WIDGET(interface.file_selector));
 }
 
 void
-save_results_cb (GtkFileSelection *selector, 
-		 gpointer 	  user_data, 
+save_results_cb (GtkWidget       *chooser, 
+		 gint		  response, 
 		 gpointer 	  data)
 {
 	FILE *fp;
 	GtkListStore *store;
 	GtkTreeIter iter;
 	gint n_children, i;
-	gchar *utf8;
+	gchar *utf8 = NULL;
 	
+	if (response != GTK_RESPONSE_OK) {
+		gtk_widget_destroy (GTK_WIDGET (chooser));
+		return;
+	}
+
 	store = interface.model;
+	g_free (interface.save_results_file);
 	
-	interface.save_results_file = (gchar *)gtk_file_selection_get_filename (GTK_FILE_SELECTION (interface.file_selector));
-	utf8 = g_filename_to_utf8 (interface.save_results_file, -1, NULL, NULL, NULL);
+	interface.save_results_file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser));
+	gtk_widget_destroy (chooser);
+	
+	if (interface.save_results_file != NULL) {
+		utf8 = g_filename_to_utf8 (interface.save_results_file, -1, NULL, NULL, NULL);
+	}
+	
+	if (utf8 == NULL) {
+		GtkWidget *dialog;
+		gchar *primary;
+		gchar *secondary;
+		
+		primary = g_strdup (_("Could not save document."));
+				     
+		secondary = g_strdup (_("You did not select a document name."));
+
+		dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+		                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+						   GTK_MESSAGE_ERROR,
+						   GTK_BUTTONS_OK,
+						   primary,
+						   secondary,
+						   NULL);
+
+		g_signal_connect (G_OBJECT (dialog),
+				"response",
+				G_CALLBACK (gtk_widget_destroy), NULL);
+					
+		gtk_widget_show (dialog);
+		g_free (primary);
+		g_free (secondary);
+		
+		return;	
+	}
+	
+	if (g_file_test (interface.save_results_file, G_FILE_TEST_IS_DIR)) {
+		GtkWidget *dialog;
+		gchar *primary;
+		gchar *secondary;
+		
+		primary = g_strdup_printf (_("Could not save \"%s\" document to \"%s\"."), 
+		                           g_path_get_basename (utf8), 
+					   g_path_get_dirname (utf8));
+		
+		secondary = g_strdup (_("The document name you selected is a folder."));
+
+		dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+		                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+						   GTK_MESSAGE_ERROR,
+						   GTK_BUTTONS_OK,
+						   primary,
+						   secondary,
+						   NULL);
+
+		g_signal_connect (G_OBJECT (dialog),
+				"response",
+				G_CALLBACK (gtk_widget_destroy), NULL);
+					
+		gtk_widget_show (dialog);
+		g_free (primary);
+		g_free (secondary);
+		
+		return;	
+	}
 	
 	if (g_file_test (interface.save_results_file, G_FILE_TEST_EXISTS)) {
 		
-		if (g_file_test (interface.save_results_file, G_FILE_TEST_IS_DIR)) {
-			GtkWidget *dialog;
-			gchar *title_msg;
-			gchar *error_msg;
-			
-			title_msg = g_strdup_printf (_("Could not save document \"\" to %s"), 
-		                                     interface.save_results_file);
-					     
-			error_msg = g_strdup_printf (_("You did not select a document name or the name selected was a folder.  The document is not saved."));
-
-			dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-			                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-							     GTK_BUTTONS_OK,
-							     title_msg,
-							     error_msg);
-
-			g_signal_connect (G_OBJECT (dialog),
-					"response",
-					G_CALLBACK (gtk_widget_destroy), NULL);
-					
-			gtk_widget_show (dialog);
-			g_free (title_msg);
-			g_free (error_msg);
-			
-			return;	
-		}
-		else {
-			GtkWidget *dialog;
-			gchar     *text;
-			gint      response;
-				 
-			text = g_strdup_printf (_("The contents of the file \"%s\" will be lost."), utf8);
-			
-			dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-			                                     0 /* flags */,
-							     GTK_BUTTONS_OK_CANCEL,
-							     _("Overwrite an existing file?"),
-							     text);
-			
-			response = gtk_dialog_run (GTK_DIALOG (dialog));
+		GtkWidget *dialog;
+		GtkWidget *button;
+		gchar     *primary;
+		gchar     *secondary;
+		gint      response;
 		
-			gtk_widget_destroy (GTK_WIDGET(dialog));
-			g_free (text);
+		primary = g_strdup_printf (_("The document \"%s\" already exists.  "
+		                             "Would you like to replace it?"), 
+					   g_path_get_basename (utf8));
+		
+		secondary = g_strdup (_("If you replace an existing file, "
+		                        "its contents will be overwritten."));
+		
+		dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+		                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+						   GTK_MESSAGE_QUESTION,
+						   GTK_BUTTONS_CANCEL,
+						   primary,
+						   secondary,
+						   NULL);	
+		
+		button = gsearchtool_button_new_with_stock_icon (_("_Replace"), GTK_STOCK_OK);
+		GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+		gtk_widget_show (button);
+
+		gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
+		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+		
+		response = gtk_dialog_run (GTK_DIALOG (dialog));
+		
+		gtk_widget_destroy (GTK_WIDGET(dialog));
+		g_free (primary);
+		g_free (secondary);
 			
-			if (response != GTK_RESPONSE_OK) return;
-		}
+		if (response != GTK_RESPONSE_OK) return;
 	}
 	
 	if ((fp = fopen (interface.save_results_file, "w")) != NULL) {
@@ -1151,28 +1358,29 @@ save_results_cb (GtkFileSelection *selector,
 	} 
 	else {
 		GtkWidget *dialog;
-		gchar *title_msg;
-		gchar *error_msg;
+		gchar *primary;
+		gchar *secondary;
 		
-		title_msg = g_strdup_printf (_("Could not save document \"%s\" to %s"), 
+		primary = g_strdup_printf (_("Could not save \"%s\" document to \"%s\"."), 
 		                             g_path_get_basename (utf8), g_path_get_dirname (utf8));
 					     
-		error_msg = g_strdup_printf ("%s",
-		_("You may not have write permissions to the document.  The document is not saved."));
-						    						
-		dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-		                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-						     GTK_BUTTONS_OK,
-						     title_msg,
-						     error_msg);
+		secondary = g_strdup (_("You may not have write permissions to the document."));
+		
+		dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+		                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+						   GTK_MESSAGE_ERROR,
+						   GTK_BUTTONS_OK,
+						   primary,
+						   secondary,
+						   NULL);
 
 		g_signal_connect (G_OBJECT (dialog),
 				"response",
 				G_CALLBACK (gtk_widget_destroy), NULL);
 					
 		gtk_widget_show (dialog);
-		g_free (title_msg);
-		g_free (error_msg);
+		g_free (primary);
+		g_free (secondary);
 	}
 	g_free (utf8);
 }
@@ -1264,3 +1472,14 @@ not_running_timeout_cb (gpointer data)
 	search_command.not_running_timeout = FALSE;
 	return FALSE;
 }
+
+void
+disable_quick_search_cb (GtkWidget 	*dialog, 
+                         gint      	response, 
+                         gpointer   	data)
+{
+	if (response == GTK_RESPONSE_OK) {
+		gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/disable_quick_search", TRUE);
+	}
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+}
