@@ -46,7 +46,7 @@ AboutShowWindow (GtkWidget *widget, gpointer user_data)
 	  NULL
   };
   /* Translator credits */
-  gchar *translator_credits = _("translator_credits");
+  gchar *translator_credits = _("translator-credits");
 
   if (about_window != NULL) {
 	  gtk_widget_show_now (about_window);
@@ -54,8 +54,8 @@ AboutShowWindow (GtkWidget *widget, gpointer user_data)
 	  return;
   }
 
-  logo = gdk_pixbuf_new_from_file (DATADIR G_DIR_SEPARATOR_S "pixmaps" G_DIR_SEPARATOR_S "gnome-log.png", NULL);
-  about_window = gnome_about_new (_("GNOME System Log Viewer"), VERSION,
+  logo = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), "logviewer", 48, 0, NULL);
+  about_window = gnome_about_new (_("System Log Viewer"), VERSION,
            			  "Copyright \xc2\xa9 1998-2003 Free Software Foundation, Inc.",
 				  _(comments),
 				  author,
